==> org.kikaineko.mock.plugin.kikainekoMocker_1.0.0.zip: fortest/AllMockMakersTest.java <==
package fortest;

import org.kikaineko.mock.textui.MockMaker;
import org.kikaineko.util.FileIO;


import junit.framework.TestCase;

public class AllMockMakersTest extends TestCase {
	public void testArrayUserTest(){
		makeMock("src\\fortest\\ArrayUserTest.java", "src\\fortest\\ArrayUser.java");
		makeMock("src\\fortest\\IntUserTest.java", "src\\fortest\\IntUser.java");
		makeMock("src\\fortest\\Visib2Test.java", "src\\fortest\\HH.java");
		makeMock("src\\fortest\\ExceptionTest.java", "src\\fortest\\ET.java");
		makeMock("src\\fortest\\SetupTest.java", "src\\fortest\\MyClassForSetup.java");
		makeMock("src\\fortest\\TeardownTest.java", "src\\fortest\\MyClassForTeardown.java");
		makeMock("src\\fortest\\beyondthetest\\SimpleSetterGetterTest.java", "src\\fortest\\beyondthetest\\SimpleSetterGetter.java");
		makeMock("src\\fortest\\di\\ForDITest.java", "src\\fortest\\di\\ForDIIntImpl2.java");
		makeMock("src\\fortest\\fields\\UsingFieldsTest.java", "src\\fortest\\fields\\Hoge.java");
		makeMock("src\\fortest\\fields\\UsingFieldsWithConstructTest.java", "src\\fortest\\fields\\Hoge2.java");
		makeMock("src\\fortest\\undef\\UndefClassUserTest.java", "src\\fortest\\undef\\UndefClassUser.java");
		makeMock("src\\fortest\\undef\\UndefUserTest.java", "src\\fortest\\undef\\UndefUser.java");
		makeMock("src\\fortest\\SimpleTokenTest.java", "src\\fortest\\SimpleToken.java");
		makeMock("src\\fortest\\SimpleTokenTest.java", "src\\fortest\\CaclTest.java");
		makeMock("src\\fortest\\free\\Class1Test.java", "src\\fortest\\free\\Class1.java");
		
	}
	private void makeMock(String testFileName,String targetFileName){
		try{
			String[] ss={"-v",testFileName};
			MockMaker.main(ss);
		}catch(Throwable t){
		    t.printStackTrace();
		    fail();
		}
		
		FileIO.cutting(targetFileName, 300);
	}
}

==> org.kikaineko.mock.plugin.kikainekoMocker_1.0.1.zip: fortest/AllMockMakersTest.java <==
package fortest;

import org.kikaineko.mock.textui.MockMaker;
import org.kikaineko.util.FileIO;


import junit.framework.TestCase;

public class AllMockMakersTest extends TestCase {
	public void testArrayUserTest(){
		makeMock("src\\fortest\\ArrayUserTest.java", "src\\fortest\\ArrayUser.java");
		makeMock("src\\fortest\\IntUserTest.java", "src\\fortest\\IntUser.java");
		makeMock("src\\fortest\\Visib2Test.java", "src\\fortest\\HH.java");
		makeMock("src\\fortest\\ExceptionTest.java", "src\\fortest\\ET.java");
		makeMock("src\\fortest\\SetupTest.java", "src\\fortest\\MyClassForSetup.java");
		makeMock("src\\fortest\\TeardownTest.java", "src\\fortest\\MyClassForTeardown.java");
		makeMock("src\\fortest\\beyondthetest\\SimpleSetterGetterTest.java", "src\\fortest\\beyondthetest\\SimpleSetterGetter.java");
		makeMock("src\\fortest\\di\\ForDITest.java", "src\\fortest\\di\\ForDIIntImpl2.java");
		makeMock("src\\fortest\\fields\\UsingFieldsTest.java", "src\\fortest\\fields\\Hoge.java");
		makeMock("src\\fortest\\fields\\UsingFieldsWithConstructTest.java", "src\\fortest\\fields\\Hoge2.java");
		makeMock("src\\fortest\\undef\\UndefClassUserTest.java", "src\\fortest\\undef\\UndefClassUser.java");
		makeMock("src\\fortest\\undef\\UndefUserTest.java", "src\\fortest\\undef\\UndefUser.java");
		makeMock("src\\fortest\\SimpleTokenTest.java", "src\\fortest\\SimpleToken.java");
		makeMock("src\\fortest\\SimpleTokenTest.java", "src\\fortest\\CaclTest.java");
		makeMock("src\\fortest\\free\\Class1Test.java", "src\\fortest\\free\\Class1.java");
		makeMock("src\\fortest\\beyondthetest\\GetterSetterTest.java", "src\\fortest\\beyondthetest\\GetterSetter.java");
		makeMock("src\\fortest\\beyondthetest\\UnknownArgTest.java", "src\\fortest\\beyondthetest\\UnknownArg.java");
		makeMock("src\\fortest\\cast\\UndefUserUserTest.java", "src\\fortest\\cast\\UUU.java",900);
		
	}
	private void makeMock(String testFileName,String targetFileName){
		makeMockLogic(testFileName, targetFileName,500);
	}
	private void makeMock(String testFileName,String targetFileName,int lines){
		makeMockLogic(testFileName, targetFileName,lines);
	}
	private void makeMockLogic(String testFileName,String targetFileName,int lines){
		try{
			String[] ss={"-v",testFileName};
			MockMaker.main(ss);
		}catch(Throwable t){
		    t.printStackTrace();
		    fail();
		}
		
		FileIO.cutting(targetFileName, lines);
	}
}
